package ui;
/*
 * FilamentSensor - A tool for filament tracking from cell images
 *
 * Copyright (C) 2011-2013 Julian Rüger
 *               2013-2014 Patricia Burger, Benjamin Eltzner
 *
 * FilPicker is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 * or see <http://www.gnu.org/licenses/>.
 */

public abstract class FilamentSensor
{
    static final String TITLE = "FilamentSensor",
                        VERSION = "0.1.7";

    public static boolean DEBUG, VERBOSE;

    /**
     * Main method. Parses command line parameters and instantiates the main
     * class.
     *
     * @param args  The String-array containing the command line arguments.
     */
    public static void main(String[] args)
    {
        DEBUG = VERBOSE = false;
        for (int arg = 0; arg < args.length; arg++)
        {
            if (args[arg].matches("-{1,2}debug"))
            {
                DEBUG = true;
            }
            else if (args[arg].matches("(-{1,2}verbose)|(-v)"))
            {
                DEBUG = VERBOSE = true;
            }
            else if (args[arg].matches("(-{1,2}help)|(-h)"))
            {
                usage();
                return;
            }
        }
        if (DEBUG)
        {
            System.out.println("Welcome to " + TITLE + " " + VERSION + "! Debug mode active.\n");
            if (VERBOSE)
            {
                System.out.println("Verbose mode active. Expect plenty of output.\n");
            }
        }

        MainWindow.open();
    }

    public static void usage()
    {
        System.out.println("Usage:\n\tjava -jar " + TITLE + "-" + VERSION + ".jar [Options]\n\n" +
        		           "Possible switches are:\n" +
        		           "\t-h,\t--help\tshow this help and exit\n" +
        		           "\t--debug\t\tstart " + TITLE + " in debug mode\n" +
        		           "\t-v,\t--verbose\tstart " + TITLE + " in verbose mode\n");
        return;
    }

}
