package ui;
/*
 * This file is part of FilamentSensor - A tool for filament tracking from cell images
 *
 * Copyright (C) 2011-2013 Julian Rüger
 *
 * FilamentSensor is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 * or see <http://www.gnu.org/licenses/>.
 */

import java.awt.*;
import java.awt.event.*;

import javax.swing.*;

import core.DataImage;

public class PopUpFilterDiff extends JFrame implements ActionListener
{
    private JPanel jp_content, jp_controls;
    private PanelImage m_panel_image;
    private JButton jb_refresh, jb_close;

    private DataImage data;

    public PopUpFilterDiff(DataImage data)
    {
        super("Delta of the most recently applied filter");
        setDefaultCloseOperation(DISPOSE_ON_CLOSE);

        this.data = data;

        jp_content = new JPanel();
        jp_content.setLayout(new BoxLayout(jp_content, BoxLayout.Y_AXIS));

        m_panel_image = new PanelImage();
        jp_content.add(m_panel_image);

        jp_controls = new JPanel();
        jp_controls.setLayout(new BoxLayout(jp_controls, BoxLayout.X_AXIS));

        jp_controls.add(Box.createHorizontalGlue());

        jb_refresh = new JButton("   Refresh   ");
        jb_refresh.addActionListener(this);
        jp_controls.add(jb_refresh);

        jp_controls.add(Box.createHorizontalGlue());

        jb_close = new JButton("  Close  ");
        jb_close.addActionListener(this);
        jp_controls.add(jb_close);

        jp_controls.add(Box.createHorizontalGlue());

        jp_content.add(jp_controls);

        setDefaultLookAndFeelDecorated(false);
        setContentPane(jp_content);

        refreshView();

        setMinimumSize(new Dimension(MainWindow.MIN_WIDTH, MainWindow.MIN_HEIGHT));
        Dimension size = MainWindow.frame().getSize();
        size.width -= 100;
        size.height -= 100;
        this.setSize(size);
        Point location = MainWindow.frame().getLocation();
        location.x += 50;
        location.y += 50;
        this.setLocation(location);
        setVisible(true);
    }

    public void refreshView()
    {
        m_panel_image.setImage(data.makeImage(DataImage.DIFF), false);
    }

    @Override
    public void actionPerformed(ActionEvent e)
    {
        Object src = e.getSource();

        if (src == jb_close)
        {
            dispose();
        }
        else if (src == jb_refresh)
        {
            refreshView();
        }
    }
}
